ProofStep

Struct ProofStep 

pub struct ProofStep(/* private fields */);
A clause introduction or deletion

This is essentially this enum, but we pack everything into 32 bits.

enum ProofStep {
    Lemma(Clause),
    Deletion(Clause),
}

Implementations

Source

impl ProofStep

pub fn lemma(clause: Clause) -> ProofStep

Create a proof step that introduces the given clause.

pub fn deletion(clause: Clause) -> ProofStep

Create a proof step that deletes the given clause.

pub fn is_deletion(self) -> bool

Return true if this proof step is a clause deletion.

pub fn clause(self) -> Clause

Return the clause that this proof step introduces or deletes.